"""Settings to access https://toar-data.fz-juelich.de"""
from typing import Tuple, Dict


def toar_data_v2_settings(sampling="daily") -> Tuple[str, Dict]:
    """
    Set url for toar-data and required headers. Headers information is not required for now.

    :param sampling: temporal resolution to access.
    :return: Service url and optional headers
    """
    if sampling == "daily":  # pragma: no branch
        TOAR_SERVICE_URL = "https://toar-data.fz-juelich.de/api/v2/analysis/statistics/"
        headers = {}
    elif sampling == "hourly" or sampling == "meta":
        TOAR_SERVICE_URL = "https://toar-data.fz-juelich.de/api/v2/"
        headers = {}
    else:
        raise NameError(f"Given sampling {sampling} is not supported, choose from either daily or hourly sampling.")
    return TOAR_SERVICE_URL, headers
